@@ -1,5 +1,6 @@
 // ignore most things
 var IgnoreFile = require("../")
+, path = require('path')
 
 // set the ignores just for this test
 var c = require("./common.js")
@@ -26,7 +27,8 @@ var expected =
   , "/c/b/a/cba"
   , "/c/b/a/.cba"
   , "/c/b/a/abc"
-  , "/c/b/a/acb" ]
+  , "/c/b/a/acb"
+  ].map(path.normalize)
 
 require("tap").test("basic ignore rules", function (t) {
   t.pass("start")
